@@ -1,8 +1,8 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2009-12-01
  * @brief  Google-Maps-backend for KGeoMap
@@ -37,6 +37,10 @@
 #include <QResizeEvent>
 #include <QAction>
 
+// Marble Widget includes
+
+#include <marble/GeoDataLatLonBox.h>
+
 // KDE includes
 
 #include <kconfiggroup.h>
@@ -59,7 +63,7 @@ public:
 
     GMInternalWidgetInfo()
     {
-        htmlWidget = 0;
+        htmlWidget = nullptr;
     }
 
     HTMLWidget* htmlWidget;
@@ -77,14 +81,14 @@ class BackendGoogleMaps::Private
 public:
 
     Private()
-    : htmlWidget(0),
-      htmlWidgetWrapper(0),
+    : htmlWidget(nullptr),
+      htmlWidgetWrapper(nullptr),
       isReady(false),
-      mapTypeActionGroup(0),
-      floatItemsActionGroup(0),
-      showMapTypeControlAction(0),
-      showNavigationControlAction(0),
-      showScaleControlAction(0),
+      mapTypeActionGroup(nullptr),
+      floatItemsActionGroup(nullptr),
+      showMapTypeControlAction(nullptr),
+      showNavigationControlAction(nullptr),
+      showScaleControlAction(nullptr),
       cacheMapType(QLatin1String("ROADMAP")),
       cacheShowMapTypeControl(true),
       cacheShowNavigationControl(true),
@@ -337,7 +341,7 @@ void BackendGoogleMaps::slotMapTypeActionTriggered(QAction* action)
 
 void BackendGoogleMaps::addActionsToConfigurationMenu(QMenu* const configurationMenu)
 {
-    KGEOMAP_ASSERT(configurationMenu!=0);
+    KGEOMAP_ASSERT(configurationMenu!=nullptr);
 
     if (!d->isReady)
         return;
@@ -368,7 +372,7 @@ void BackendGoogleMaps::addActionsToConfigurationMenu(QMenu* const configuration
 
 void BackendGoogleMaps::saveSettingsToGroup(KConfigGroup* const group)
 {
-    KGEOMAP_ASSERT(group != 0);
+    KGEOMAP_ASSERT(group != nullptr);
 
     if (!group)
         return;
@@ -381,7 +385,7 @@ void BackendGoogleMaps::saveSettingsToGroup(KConfigGroup* const group)
 
 void BackendGoogleMaps::readSettingsFromGroup(const KConfigGroup* const group)
 {
-    KGEOMAP_ASSERT(group != 0);
+    KGEOMAP_ASSERT(group != nullptr);
 
     if (!group)
         return;
@@ -739,7 +743,7 @@ void BackendGoogleMaps::updateClusters()
         {
             QPoint clusterCenterPoint;
             // TODO: who calculates the override values?
-            const QPixmap clusterPixmap = s->worldMapWidget->getDecoratedPixmapForCluster(currentIndex, 0, 0, &clusterCenterPoint);
+            const QPixmap clusterPixmap = s->worldMapWidget->getDecoratedPixmapForCluster(currentIndex, nullptr, nullptr, &clusterCenterPoint);
 
             setClusterPixmap(currentIndex, clusterCenterPoint, clusterPixmap);
         }
@@ -782,7 +786,7 @@ bool BackendGoogleMaps::geoCoordinates(const QPoint& point, GeoCoordinates* cons
 
 QSize BackendGoogleMaps::mapSize() const
 {
-    KGEOMAP_ASSERT(d->htmlWidgetWrapper != 0);
+    KGEOMAP_ASSERT(d->htmlWidgetWrapper != nullptr);
 
     return d->htmlWidgetWrapper->size();
 }
@@ -1012,7 +1016,7 @@ void BackendGoogleMaps::slotThumbnailAvailableForIndex(const QVariant& index, co
         {
             QPoint clusterCenterPoint;
             // TODO: who calculates the override values?
-            const QPixmap clusterPixmap = s->worldMapWidget->getDecoratedPixmapForCluster(i, 0, 0, &clusterCenterPoint);
+            const QPixmap clusterPixmap = s->worldMapWidget->getDecoratedPixmapForCluster(i, nullptr, nullptr, &clusterCenterPoint);
 
             setClusterPixmap(i, clusterCenterPoint, clusterPixmap);
 
@@ -1192,7 +1196,7 @@ void BackendGoogleMaps::setActive(const bool state)
             setShowNavigationControl(d->cacheShowNavigationControl);
             setShowScaleControl(d->cacheShowScaleControl);
 
-            /// @TODO update tracks more gently
+            /// @todo update tracks more gently
             slotTracksChanged(d->trackChangeTracker);
             d->trackChangeTracker.clear();
         }
@@ -1213,12 +1217,12 @@ void BackendGoogleMaps::releaseWidget(KGeoMapInternalWidgetInfo* const info)
     disconnect(d->htmlWidget, SIGNAL(selectionHasBeenMade(KGeoMap::GeoCoordinates::Pair)),
                this, SLOT(slotSelectionHasBeenMade(KGeoMap::GeoCoordinates::Pair)));
 
-    d->htmlWidget->setSharedKGeoMapObject(0);
+    d->htmlWidget->setSharedKGeoMapObject(nullptr);
     d->htmlWidgetWrapper->removeEventFilter(this);
 
-    d->htmlWidget        = 0;
-    d->htmlWidgetWrapper = 0;
-    info->currentOwner   = 0;
+    d->htmlWidget        = nullptr;
+    d->htmlWidgetWrapper = nullptr;
+    info->currentOwner   = nullptr;
     info->state          = KGeoMapInternalWidgetInfo::InternalWidgetReleased;
     d->isReady           = false;
 
